@@ -1,4 +1,5 @@
 import inspect
+import numpy as np
 from openpnm.utils import PrintableDict, logging, Workspace
 from openpnm.utils.misc import is_valid_propname
 from openpnm.utils import prettify_logger_message
@@ -9,21 +10,33 @@ ws = Workspace()
 class ModelsDict(PrintableDict):
     r"""
     This subclassed dictionary is assigned to the ``models`` attribute of
-    all objects that inherit from the ``ModelsMixin`` class.  Each dictionary
-    entry corresponds to an entry in the target object's dictionary, and
-    contains the models and associated parameters for generating the model.
+    all objects that inherit from the ``ModelsMixin`` class.  Each
+    dictionary entry corresponds to an entry in the target object's
+    dictionary, and contains the models and associated parameters for
+    generating the model.
 
-    The main features of this subclass are three methods the help resolve the
-    order in which models should be called: ``dependency_list``,
+    The main features of this subclass are three methods the help resolve
+    the order in which models should be called: ``dependency_list``,
     ``dependency_graph``, and ``dependency_map``.
 
     """
 
+    def _find_parent(self):
+        r"""
+        Finds and returns the parent object to self.
+        """
+        for proj in ws.values():
+            for obj in proj:
+                if hasattr(obj, "models"):
+                    if obj.models is self:
+                        return obj
+        raise Exception("No parent object found!")
+
     def dependency_list(self):
         r"""
-        Returns a list of dependencies in the order with which they should be
-        called to ensure data is calculated by one model before it's asked for
-        by another.
+        Returns a list of dependencies in the order with which they should
+        be called to ensure data is calculated by one model before it's
+        asked for by another.
 
         Notes
         -----
@@ -55,8 +68,9 @@ class ModelsDict(PrintableDict):
         Parameters
         ----------
         deep : bool, optional
-            Defines whether intra- or inter-object dependency graph is desired.
-            Default is False, i.e. only returns dependencies within the object.
+            Defines whether intra- or inter-object dependency graph is
+            desired. Default is False, i.e. only returns dependencies
+            within the object.
 
         See Also
         --------
@@ -89,6 +103,11 @@ class ModelsDict(PrintableDict):
 
         dtree = nx.DiGraph()
         models = list(self.keys())
+        # Fetch model-less props: those w/o any model, like temperature
+        # otherwise, they won't get picked up in the dependency graph.
+        all_props = list(self._find_parent().keys())
+        exclude_keys = ["pore.all", "throat.all"]
+        pure_props = np.setdiff1d(all_props, models + exclude_keys).tolist()
 
         for model in models:
             dtree.add_node(model)
@@ -100,24 +119,27 @@ class ModelsDict(PrintableDict):
             # Add depenency from model's parameters
             for d in dependencies:
                 if not deep:
-                    if d in models:
+                    if d in models + pure_props:
                         dtree.add_edge(d, model)
                 else:
                     dtree.add_edge(d, model)
 
         return dtree
 
-    def dependency_map(self, ax=None, figsize=None, deep=False, style='shell'):
+    def dependency_map(self,
+                       ax=None,
+                       figsize=None,
+                       deep=False,
+                       style='shell'):  # pragma: no cover
         r"""
         Create a graph of the dependency graph in a decent format
 
         Parameters
         ----------
         ax : matplotlib.axis, optional
-            Matplotlib axis object on which dependency map is to be drawn
-
+            Matplotlib axis object on which dependency map is to be drawn.
         figsize : tuple, optional
-            Tuple containing frame size
+            Tuple containing frame size.
 
         See Also
         --------
@@ -128,33 +150,47 @@ class ModelsDict(PrintableDict):
         import networkx as nx
         import matplotlib.pyplot as plt
 
-        dtree = self.dependency_graph(deep=deep)
-        labels = {}
-        for node in dtree.nodes:
-            if node.startswith("pore."):
-                value = node.replace("pore.", "[P] ")
-            elif node.startswith("throat."):
-                value = node.replace("throat.", "[T] ")
-            labels[node] = value
-
         if ax is None:
             fig, ax = plt.subplots()
         if figsize is not None:
             fig.set_size_inches(figsize)
 
+        labels = {}
+        dtree = self.dependency_graph(deep=deep)
+        for node in dtree.nodes:
+            labels[node] = node.split(".")[1]
+
+        node_shapes = {}
+        for node in dtree.nodes:
+            if node.startswith("pore"):
+                node_shapes[node] = "o"
+            else:
+                node_shapes[node] = "s"
+        nx.set_node_attributes(dtree, node_shapes, "node_shape")
+
         style = style.replace('draw_', '')
-        method = getattr(nx, 'draw_' + style)
-        method(dtree,
-               labels=labels,
-               with_labels=True,
-               edge_color='lightgrey',
-               font_size=12,
-               width=3.0)
+        draw = getattr(nx, 'draw_' + style)
+
+        pore_props = [prop for prop in dtree.nodes if prop.startswith("pore")]
+        throat_props = [prop for prop in dtree.nodes if prop.startswith("throat")]
+
+        for props, color, shape in zip([pore_props, throat_props],
+                                       ["yellowgreen", "coral"],
+                                       ["o", "s"]):
+            draw(dtree,
+                 nodelist=props,
+                 node_shape=shape,
+                 labels=labels,
+                 with_labels=True,
+                 edge_color='lightgrey',
+                 node_color=color,
+                 font_size=12,
+                 width=2.0)
 
         ax = plt.gca()
         ax.margins(x=0.2, y=0.02)
 
-        # return ax.figure
+        return ax
 
     def __str__(self):
         horizontal_rule = '―' * 85
@@ -208,17 +244,17 @@ class ModelWrapper(dict):
 class ModelsMixin:
     r"""
     This class is meant to be combined by the Base class in multiple
-    inheritence.  This approach is used since Network and Algorithm do not
-    need to have any ``models`` attribute, while Phase, Geometry, and Physics
-    do.  By using a mixin class, all objects can inherit from Base while
-    the model functionality can be added only where needed.
+    inheritence. This approach is used since Network and Algorithm do not
+    need to have any ``models`` attribute, while Phase, Geometry, and
+    Physics do. By using a mixin class, all objects can inherit from Base
+    while the model functionality can be added only where needed.
 
     Notes
     -----
-    The following table gives a brief overview of the methods that are added
-    to the object by this mixin.  In addition to these methods, a ``models``
-    attribute is also added, which is a dictionary that contains all of the
-    models and their parameters.
+    The following table gives a brief overview of the methods that are
+    added to the object by this mixin.  In addition to these methods, a
+    ``models`` attribute is also added, which is a dictionary that
+    contains all of the models and their parameters.
 
     +----------------------+--------------------------------------------------+
     | Method or Attribute  | Functionality                                    |
@@ -245,8 +281,8 @@ class ModelsMixin:
     >>> print(temp.num_pores())
     3
 
-    But also has those needed for working with models.  For instance, a simple
-    model can be added as follows:
+    But also has those needed for working with models.  For instance, a
+    simple model can be added as follows:
 
     >>> temp.add_model(propname='pore.test',
     ...                model=op.models.misc.constant,
@@ -254,8 +290,8 @@ class ModelsMixin:
     >>> print(temp['pore.test'])
     [2 2 2]
 
-    All the models and their respective parameters are stored in the ``models``
-    attribute:
+    All the models and their respective parameters are stored in the
+    ``models`` attribute:
 
     >>> print(temp.models)
     ―――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――
